@@ -51,17 +51,17 @@ def load_xyz(f_name: str, atomic_numbers: bool = False):
 
     Parameters
     ----------
-        f_name (str) :
+        f_name : str
             File name
-        atomic_numbers (bool, optional) :
+        atomic_numbers : bool, optional
             If true, will read xyz file with atomic numbers and convert
             to labels
 
     Returns
     -------
-        _labels (list) :
+        _labels : list
             atomic labels
-        _coords (list) :
+        _coords : list
             list of 3 element lists containing xyz coordinates of each atom
     """
 
@@ -80,27 +80,27 @@ def load_xyz(f_name: str, atomic_numbers: bool = False):
 
 
 def save_xyz(f_name: str, labels: list, coords: list,
-             with_numbers: bool = False, verbose: bool = True, mask: list = [],
-             atomic_numbers: bool = False):
+             with_numbers: bool = False, verbose: bool = True,
+             mask: list = [], atomic_numbers: bool = False):
     """
-    Add numbers to a list of atomic labels
+    Save an xyz file containing labels and coordinates
 
     Parameters
     ----------
-        f_name (str) :
+        f_name : str
             File name
-        labels (list) :
+        labels : list
             atomic labels
-        coords (list) :
+        coords : list
             list of 3 element lists containing xyz coordinates of each atom
-        with_numbers (bool, optional) :
+        with_numbers : bool, optional
             If True, add/overwrite numbers to labels before printing
-        verbose (bool, optional) :
+        verbose : bool, optional
             Print information on filename to screen
-        mask (list, optional) :
+        mask : list, optional
             n_atom list of 0 (exclude) and 1 (include) indicating which
             atoms to print
-        atomic_numbers (bool, optional) :
+        atomic_numbers : bool, optional
             If true, will save xyz file with atomic numbers
 
     Returns
@@ -151,12 +151,12 @@ def remove_numbers(labels: list):
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             atomic labels
 
     Returns
     -------
-        labels_nn (list) :
+        labels_nn : list
             atomic labels without numbers
     """
 
@@ -178,16 +178,16 @@ def add_numbers(labels: list, style: str = 'per_element'):
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             atomic labels
-        style (str, optional) :
+        style : str, optional
             {'per_element', 'sequential'}
                 'per_element' : Number by element e.g. Dy1, Dy2, N1, N2, etc.
                 'sequential' : Number the atoms 1->N regardless of element
 
     Returns
     -------
-        labels_wn (list) :
+        labels_wn : list
             atomic labels with numbers
     """
 
@@ -222,12 +222,12 @@ def count_n_atoms(form_str: str):
 
     Parameters
     ----------
-        form_str (str) :
+        form_str : str
             chemical formula string
 
     Returns
     -------
-        n_atoms (int) :
+        n_atoms : int
             number of atoms in chemical formula
     """
 
@@ -245,14 +245,14 @@ def index_elements(labels: list, shift: int = 0):
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             atomic labels
-        shift (int, optional):
+        shift : int, optional
             additive shift to apply to all indices
 
     Returns
     -------
-        ele_index (dict) :
+        ele_index : dict
             dictionary of element (keys) and indices (values)
     """
 
@@ -275,11 +275,11 @@ def count_elements(labels: list):
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             atomic labels
     Returns
     -------
-        ele_count (dict) :
+        ele_count : dict
             dictionary of elements (keys) and counts (vals)
     """
 
@@ -296,18 +296,39 @@ def count_elements(labels: list):
     return ele_count
 
 
+def get_formula(labels: list):
+    """
+    Returns empirical formula in alphabetical order given a list of labels
+
+    Parameters
+    ----------
+        labels : list
+            atomic labels
+    Returns
+    -------
+        formula : str
+            Empirical formula in alphabetical order
+    """
+
+    formdict = count_elements(labels)
+
+    formula = formdict_to_formstr(formdict)
+
+    return formula
+
+
 def formstr_to_formdict(form_str: str):
     """
     Converts formula string into dictionary of {atomic label:quantity} pairs
 
     Parameters
     ----------
-        form_string (str) :
+        form_string : str
             Chemical formula as string
 
     Returns
     -------
-        form_dict (dict) :
+        form_dict : dict
             dictionary of {atomic label:quantity} pairs
     """
 
@@ -325,19 +346,19 @@ def formstr_to_formdict(form_str: str):
 def formdict_to_formstr(form_dict: dict, include_one: bool = False):
     """
     Converts dictionary of {atomic label:quantity} pairs into
-    a single formula string
+    a single formula string in alphabetical order
 
     Parameters
     ----------
-        form_dict (dict) :
+        form_dict : dict
             dictionary of {atomic label:quantity} pairs
-        include_one (bool, optional) :
+        include_one : bool, optional
             Include 1 in final chemical formula e.g. C1H4
 
     Returns
     -------
-        form_string (str) :
-            Chemical formula as string
+        form_string : str
+            Chemical formula as string in alphabetical order
     """
 
     # Formula labels and quantities as separate lists with same order
@@ -375,12 +396,12 @@ def contains_metal(form_string: str):
 
     Parameters
     ----------
-        form_string (str) :
+        form_string : str
             Chemical formula as string
 
     Returns
     -------
-        metal_found (int) :
+        metal_found : int
             Combined atomic labels
     """
     metal_found = 0
@@ -400,20 +421,20 @@ def combine_xyz(labels_1: list, labels_2: list,
 
     Parameters
     ----------
-        labels_1 (list) :
+        labels_1 : list
             Atomic labels
-        coords_1 (list) :
+        coords_1 : list
             list of lists of xyz coordinates of each atom
-        labels_2 (list) :
+        labels_2 : list
             Atomic labels
-        coords_2 (list) :
+        coords_2 : list
             list of lists of xyz coordinates of each atom
 
     Returns
     -------
-        labels (list) :
+        labels : list
             Combined atomic labels
-        coords (list) :
+        coords : list
             Combined list of lists of xyz coordinates of each atom
     """
 
@@ -432,16 +453,16 @@ def get_neighborlist(labels: list, coords: list, adjust_cutoff: dict = {}):
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             Atomic labels
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
-        adjust_cutoff (dict, optional) :
+        adjust_cutoff : dict, optional
             dictionary of atoms (keys) and new cutoffs (values)
 
     Returns
     -------
-        neigh_list (ASE neighbourlist object) :
+        neigh_list : ASE neighbourlist object
             Neighbourlist for system
     """
 
@@ -479,16 +500,16 @@ def get_adjacency(labels: list, coords: list, adjust_cutoff: dict = {},
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             Atomic labels
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
-        adjust_cutoff (dict, optional) :
+        adjust_cutoff : dict, optional
             dictionary of atoms (keys) and new cutoffs (values)
 
     Returns
     -------
-        adjacency (numpy array) :
+        adjacency : np.array
             Adjacency matrix with same order as labels/coords
     """
 
@@ -520,28 +541,28 @@ def get_bonds(labels: list, coords: list, neigh_list=None,
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             Atomic labels
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
 
     Keyword arguments:
-        neigh_list (ASE neighbourlist object, optional) :
+        neigh_list : ASE neighbourlist object, optional
             neighbourlist of system
-        f_name (str, optional) :
+        f_name : str, optional
             filename to save bond list to
-        save (bool, optional) :
+        save : bool, optional
             Save bond list to file
-        verbose (bool, optional :
+        verbose : bool, optional
             Print number of bonds to screen
-        style (str, optional :
+        style : str, optional
             {'index','label'}
                 indices : Bond list contains atom number
                 labels  : Bond list contains atom label
 
     Returns
     -------
-        bonds (list) :
+        bonds : list
             list of unique bonds (atom pairs)
     """
 
@@ -608,26 +629,26 @@ def get_angles(labels: list, coords: list, neigh_list=None,
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             Atomic labels
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
-        neigh_list (ASE neighbourlist object, optional) :
+        neigh_list : ASE neighbourlist object, optional
             neighbourlist of system
-        f_name (str, optional) :
+        f_name : str, optional
             filename to save angle list to
-        save (bool, optional) :
+        save : bool, optional
             Save angle list to file
-        verbose (bool, optional) :
+        verbose : bool, optional
             Print number of angles to screen
-        style (str, optional) :
+        style : str, optional
             {'index','label'}
                 indices : Angle list contains atom number
                 labels  : Angle list contains atom label
 
     Returns
     -------
-        angles (list) :
+        angles : list
             list of unique angles (atom trios)
     """
 
@@ -695,26 +716,26 @@ def get_dihedrals(labels: list, coords: list, neigh_list=None,
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             Atomic labels
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
-        neigh_list (ASE neighbourlist object, optional) :
+        neigh_list : ASE neighbourlist object, optional
             neighbourlist of system
-        f_name (str, optional) :
+        f_name : str, optional
             filename to save angle list to
-        save (bool, optional) :
+        save : bool, optional
             Save angle list to file
-        verbose (bool, optional) :
+        verbose : bool, optional
             Print number of dihedrals to screen
-        style (str, optional) :
+        style : str, optional
             {'index','label'}
                 indices : Dihedral list contains atom number
                 labels  : Dihedral list contains atom label
 
     Returns
     -------
-        dihedrals (list) :
+        dihedrals : list
             list of unique dihedrals (atom quads)
     """
 
@@ -785,12 +806,12 @@ def lab_to_num(labels: list):
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             Atomic labels
 
     Returns
     -------
-        numbers (list) :
+        numbers : list
             Atomic numbers
     '''
 
@@ -807,14 +828,14 @@ def num_to_lab(numbers: list, numbered: bool = True):
 
     Parameters
     ----------
-        numbers (list) :
+        numbers : list
             Atomic numbers
-        numbered (bool, optional) :
+        numbered : bool, optional
             Add indexing number to end of atomic labels
 
     Returns
     -------
-        labels (list) :
+        labels : list
             Atomic labels
     '''
 
@@ -834,12 +855,12 @@ def reflect_coords(coords: list):
 
     Parameters
     ----------
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
 
     Returns
     -------
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
 
     """
@@ -883,40 +904,40 @@ def remove_broken(labels: list, coords: list, formulae: list,
 
     Parameters
     ----------
-        labels (list) :
+        labels : list
             list of atomic labels
-        coords (list) :
+        coords : list
             list of lists of xyz coordinates of each atom
-        formulae (list) :
+        formulae : list
             list of chemical formulae stored as dictionaries with atomic
             symbol (key) count (val) pairs
-        adjust_cutoff (dict, optional) :
+        adjust_cutoff : dict, optional
             dictionary of atoms (keys) and new cutoffs (values)
-        verbose (bool, optional) :
+        verbose : bool, optional
             print molecule count to screen
-        save (bool, optional) :
+        save : bool, optional
             Save molecules and incomplete fragments to separate xyz files
-        frag_f_name (str, optional) :
+        frag_f_name : str, optional
             Name for xyz file containing fragmented structures
-        clean_f_name (str, optional) :
+        clean_f_name : str, optional
             Name for xyz file containing full molecules
-        mask (list, optional) :
+        mask : list, optional
             list of 0 (exclude) and 1 (include) for each element
                 - if used, final lists will exclude masked elements
-        skip (list, optional) :
+        skip : list, optional
             List of atomic indices which shall not be visited when tracing
             bonding network
     Returns
     -------
-        labels_clean (list) :
+        labels_clean : list
             list of atomic labels for full molecules
         coords_clean (list)  :
             list of lists of xyz coordinates of each atom for full molecules
-        labels_fragments (list) :
+        labels_fragments : list
             list of atomic labels for fragments
-        coords_fragments (list) :
+        coords_fragments : list
             list of lists of xyz coordinates of each atom for fragments
-        mol_indices     (dict) :
+        mol_indices     : dict
             dictionary containing indices of complete molecules -
                 keys = molecular formula,
                 vals = list of lists of atomic indices
@@ -1095,18 +1116,18 @@ def _mask_list(_list: list, mask: list, opp_mask: bool = False):
 
     Parameters
     ----------
-        _list (list) :
+        _list : list
             list to mask
-        mask (list) :
+        mask : list
             list of 0 (exclude) and 1 (include) for each element
 
-        opp_mask (bool, optional) :
+        opp_mask : bool, optional
             Apply mask in opposite fashion:
                 0 (include) and 1 (exclude)
 
     Returns
     -------
-        _list_masked (float) : Masked list
+        _list_masked : float Masked list
     """
 
     # Flip mask other way around if requested
@@ -1127,14 +1148,14 @@ def _reorder_list(_list: list, order: list):
 
     Parameters
     ----------
-        _list (list) :
+        _list : list
             list to reorder
-        order (list) :
+        order : list
             New order for list
 
     Returns
     -------
-        _list_reordered (float) :
+        _list_reordered : float
             Reordered list
     """
 
@@ -1152,14 +1173,14 @@ def _calculate_rmsd(coords_1: list, coords_2: list):
 
     Parameters
     ----------
-        coords_1 (list) :
+        coords_1 : list
             list of lists of xyz coordinates of each atom
-        coords_2 (list) :
+        coords_2 : list
             list of lists of xyz coordinates of each atom
 
     Returns
     -------
-        rmsd (float) :
+        rmsd : float
             Root mean square of norms of deviation between two structures
     """
 
@@ -1194,23 +1215,23 @@ def calculate_rmsd(coords_1: list, coords_2: list, mask_1: list = [],
 
     Parameters
     ----------
-        coords_1 (list) :
+        coords_1 : list
             list of lists of xyz coordinates of each atom
-        coords_2 (list) :
+        coords_2 : list
             list of lists of xyz coordinates of each atom
 
-        mask_1 (list) :
+        mask_1 : list
             list of 0 (exclude) and 1 (include) for each element in coords_1
-        mask_2 (list) :
+        mask_2 : list
             list of 0 (exclude) and 1 (include) for each element in coords_2
-        order_1 (list) :
+        order_1 : list
             list of new indices for coords_1 - applied BEFORE masking
-        order_2 (list) :
+        order_2 : list
             list of new indices for coords_2 - applied BEFORE masking
 
     Returns
     -------
-        rmsd (float) :
+        rmsd : float
             Root mean square of norms of deviation between two structures
     """
 
@@ -1258,18 +1279,18 @@ def rotate_coords(coords: list, alpha: float, beta: float, gamma: float):
 
     Parameters
     ----------
-        coords_1 (list) :
+        coords_1 : list
             list of lists of xyz coordinates of each atom
-        alpha (float) :
+        alpha : float
             alpha angle in radians
-        beta (float)  :
+        beta : float
             beta  angle in radians
-        gamma (float) :
+        gamma : float
             gamma angle in radians
 
     Returns
     -------
-        rot_coords (list) :
+        rot_coords : list
             list of lists of xyz coordinates of each atom after rotation
     """
 
@@ -1312,23 +1333,23 @@ def minimise_rmsd(coords_1: list, coords_2: list, mask_1: list = [],
 
     Parameters
     ----------
-        coords_1 (list) :
+        coords_1 : list
             list of lists of xyz coordinates of each atom
-        coords_2 (list) :
+        coords_2 : list
             list of lists of xyz coordinates of each atom
 
         mask_1 (list)  :
             list of 0 (exclude) and 1 (include) for each element in coords_1
         mask_2 (list)  :
             list of 0 (exclude) and 1 (include) for each element in coords_2
-        order_1 (list) :
+        order_1 : list
             list of new indices for coords_1 - applied BEFORE masking
-        order_2 (list) :
+        order_2 : list
             list of new indices for coords_2 - applied BEFORE masking
 
     Returns
     -------
-        rmsd (float) :
+        rmsd : float
             Root mean square of norms of deviation between two structures
     """
 
@@ -1382,16 +1403,16 @@ def _rotate_and_rmsd(angs: list, coords_1: list, coords_2: list):
 
     Parameters
     ----------
-        coords_1 (list) :
+        coords_1 : list
             list of lists of xyz coordinates of each atom of first system
-        coords_2 (list) :
+        coords_2 : list
             list of lists of xyz coordinates of each atom of second system
-        angs (list) :
+        angs : list
             alpha, beta, gamma in radians
 
     Returns
     -------
-        rot_coords (list) :
+        rot_coords : list
             list of lists of xyz coordinates of each atom after rotation
     """
 
